@@ -23,6 +23,7 @@
 #include "bupverificationjob.h"
 #include "buprepairjob.h"
 #include "kupdaemon.h"
+#include "kupdaemon_debug.h"
 #include "rsyncjob.h"
 
 #include <QDBusConnection>
@@ -41,8 +42,8 @@ static QString sPwrMgmtInhibitInterface = QStringLiteral("org.freedesktop.PowerM
 static QString sPwrMgmtInterface = QStringLiteral("org.freedesktop.PowerManagement");
 
 PlanExecutor::PlanExecutor(BackupPlan *pPlan, KupDaemon *pKupDaemon)
-   :QObject(pKupDaemon), mState(NOT_AVAILABLE), mPlan(pPlan), mQuestion(NULL),
-     mFailNotification(NULL), mIntegrityNotification(NULL), mRepairNotification(NULL),
+   :QObject(pKupDaemon), mState(NOT_AVAILABLE), mPlan(pPlan), mQuestion(nullptr),
+     mFailNotification(nullptr), mIntegrityNotification(nullptr), mRepairNotification(nullptr),
      mKupDaemon(pKupDaemon), mSleepCookie(0)
 {
 	QString lCachePath = QString::fromLocal8Bit(qgetenv("XDG_CACHE_HOME").constData());
@@ -85,7 +86,7 @@ QString PlanExecutor::currentActivityTitle() {
 		case BackupPlan::MEDIUM:
 			return i18nc("status in tooltip", "New backup suggested");
 		case BackupPlan::BAD:
-			return i18nc("status in tooltip", "New backup neeeded");
+			return i18nc("status in tooltip", "New backup needed");
 		case BackupPlan::NO_STATUS:
 			return QStringLiteral("");
 		default:
@@ -182,7 +183,7 @@ void PlanExecutor::askUser(const QString &pQuestion) {
 void PlanExecutor::discardUserQuestion() {
 	if(mQuestion) {
 		mQuestion->deleteLater();
-		mQuestion = NULL;
+		mQuestion = nullptr;
 	}
 }
 
@@ -212,7 +213,7 @@ void PlanExecutor::notifyBackupFailed(KJob *pFailedJob) {
 void PlanExecutor::discardFailNotification() {
 	if(mFailNotification) {
 		mFailNotification->deleteLater();
-		mFailNotification = NULL;
+		mFailNotification = nullptr;
 	}
 }
 
@@ -224,7 +225,7 @@ void PlanExecutor::notifyBackupSucceeded() {
 }
 
 void PlanExecutor::showLog() {
-	KRun::runUrl(QUrl::fromLocalFile(mLogFilePath), QStringLiteral("text/x-log"), NULL);
+	KRun::runUrl(QUrl::fromLocalFile(mLogFilePath), QStringLiteral("text/x-log"), nullptr);
 }
 
 void PlanExecutor::startIntegrityCheck() {
@@ -295,7 +296,7 @@ void PlanExecutor::integrityCheckFinished(KJob *pJob) {
 void PlanExecutor::discardIntegrityNotification() {
 	if(mIntegrityNotification) {
 		mIntegrityNotification->deleteLater();
-		mIntegrityNotification = NULL;
+		mIntegrityNotification = nullptr;
 	}
 }
 
@@ -322,7 +323,7 @@ void PlanExecutor::repairFinished(KJob *pJob) {
 void PlanExecutor::discardRepairNotification() {
 	if(mRepairNotification) {
 		mRepairNotification->deleteLater();
-		mRepairNotification = NULL;
+		mRepairNotification = nullptr;
 	}
 }
 
@@ -406,7 +407,7 @@ void PlanExecutor::showBackupFiles() {
 		lArgs << mDestinationPath;
 		KProcess::startDetached(QStringLiteral("kup-filedigger"), lArgs);
 	} else if(mPlan->mBackupType == BackupPlan::RsyncType) {
-		KRun::runUrl(QUrl::fromLocalFile(mDestinationPath), QStringLiteral("inode/directory"), NULL);
+		KRun::runUrl(QUrl::fromLocalFile(mDestinationPath), QStringLiteral("inode/directory"), nullptr);
 	}
 }
 
@@ -416,8 +417,8 @@ BackupJob *PlanExecutor::createBackupJob() {
 	} else if(mPlan->mBackupType == BackupPlan::RsyncType) {
 		return new RsyncJob(*mPlan, mDestinationPath, mLogFilePath, mKupDaemon);
 	}
-	qWarning("Invalid backup type in configuration!");
-	return NULL;
+	qCWarning(KUPDAEMON) << "Invalid backup type in configuration!";
+	return nullptr;
 }
 
 bool PlanExecutor::powerSaveActive() {
